APIVERSION_URL          = 'http://api.unknownvpn.org/apiversion'
ACCOUNTINFO_URL         = 'http://api.unknownvpn.org/accountinfo'
GETSERVICES_URL         = 'http://api.unknownvpn.org/getservices'
GETPRICES_URL           = 'http://api.unknownvpn.org/getprices'
GETSERVERS_URL          = 'http://api.unknownvpn.org/getservers'
GETSERVICELICENSE_URL   = 'http://api.unknownvpn.org/getservicelicense'
CHANGELICENSE_URL       = 'http://api.unknownvpn.org/changelicense'
BUYSERVICE_URL          = 'http://api.unknownvpn.org/buyservice'
GETINFO_URL             = 'http://api.unknownvpn.org/getinfo'
GETLINKS_URL            = 'http://api.unknownvpn.org/getlinks'
CHANGEPROTOCOL_URL      = 'http://api.unknownvpn.org/changeprotocol'
CHANGECONNECTIONTYPE_URL= 'http://api.unknownvpn.org/changetype'
CHANGELINK_URL          = 'http://api.unknownvpn.org/changelink'
GETCONNECTIONS_URL      = 'http://api.unknownvpn.org/getconnections'
CHANGELOCATION_URL      = 'http://api.unknownvpn.org/changelocation'
CHANGENAME_URL          = 'http://api.unknownvpn.org/changename'
BUYMOREUSER_URL         = 'http://api.unknownvpn.org/buymoreuser'
BUYMORETRAFFIC_URL      = 'http://api.unknownvpn.org/buymoretraffic'
RENEWSERVICE_URL        = 'http://api.unknownvpn.org/extensionservice'
AUTOPAY_URL             = 'http://api.unknownvpn.org/setautopay'